@@ -1,17 +1,17 @@
 ;(function(){
   var map = {
-  "commitId": "1e9d764a2206cf61f9390ed0376a1d006946cbc0",
-  "branchName": "release",
-  "buildTime": "Wed, 21 Dec 2022 11:00:25 GMT",
-  "buildVersion": "264",
+  "commitId": "a29fbaef9716aeb964cab7fdbf9900190e316a58",
+  "branchName": "release-client-5.13.5",
+  "buildTime": "Mon, 16 Jan 2023 08:07:55 GMT",
+  "buildVersion": "5.1.277",
   "css": [
-    "@zoom/client-calendar/static/css/vendors~app.b826cb0e.css",
-    "@zoom/client-calendar/static/css/app.6d6add54.css"
+    "@zoom/client-calendar/static/css/vendors~app.07e6810a.css",
+    "@zoom/client-calendar/static/css/app.1ed23e5d.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/vendors~app.0faa88e1.js",
-    "@zoom/client-calendar/static/js/zoomUI~app.b0473b30.js",
-    "@zoom/client-calendar/static/js/app.21474ea4.js"
+    "@zoom/client-calendar/static/js/vendors~app.0316c293.js",
+    "@zoom/client-calendar/static/js/zoomUI~app.78a33c3b.js",
+    "@zoom/client-calendar/static/js/app.a9d45ad8.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
