@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "0b39fc545fd873d1e91002e7017df56f71f75671",
-  "branchName": "release",
-  "buildTime": "Thu, 15 Dec 2022 14:37:43 GMT",
-  "buildVersion": "5.1.164",
+  "commitId": "8808faed5f00d377b127b409c9378a23509da0c7",
+  "branchName": "release-client-5.13.5",
+  "buildTime": "Wed, 11 Jan 2023 02:23:12 GMT",
+  "buildVersion": "5.1.171",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.7f57ae19.css",
     "@zoom/client-scheduler/static/css/index.e12145da.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.73f97f40.js",
-    "@zoom/client-scheduler/static/js/index.475fe986.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.1f90189b.js",
+    "@zoom/client-scheduler/static/js/index.4b129444.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
